![logo](PopGenSims.png)

## Create population genetics simulations

This package builds off of [PopGen.jl](http://github.com/pdimens/PopGen.jl) and 
simulates offspring that would be generated under certain conditions. With this package you can simulate the offspring of specific individuals, simulate full-sibs, half-sibs, unrelated individuals, and parent-offspring pairs for use with PopGen.jl.

### Installation
```julia
julia>]

pkg(v1.5)> add "http://github.com/pdimens/PopGenSims.jl"
```

### Usage
#### Import the package
```
julia> using PopGenSims
```

#### Import the data
```
# to use included dataset
julia> cats = nancycats()

# to use your own data
julia> data = read_from("path/to/filename.ext", kwargs...);
```

#### Perform a cross
The `cross` function for a simple parental cross from individuals in the same `PopData` object follows the syntax
```
cross(::PopData, parent1::String, parent2::String; n::Int)
```
where `parent1` and `parent2` are strings of the names of the parents in the PopData, and the keyword `n` specifies the number of offspring you would like to simulate.

##### example
```
julia> f1 = cross(data, "sample1", "sample2", n = 100000) ;
```

#### Perform a backcross
This syntax uses the `Pair` notation of `PopData => Parent` to specify inputs.
```
cross(PopData => "Parent1Name", PopData => "Parent2Name", n::Int, generation::String)
```
where again `n` is a keyword argument for the number of offspring to produce, and `generation` is a keyword argument for the `population` identity to the assign the offspring.

##### example
``` 
julia> f2_backcross = cross(data => "sample1", f1 => "offspring_99", n = 100000, generation = "F2") ;

# merge PopData objects
crossed_sims = append(data, f1)
```

Currently, `PopGenSims` can create crosses for:
- haploids (ploidy = 1)
- diploids (ploidy = 2)
- tetraploids (ploidy = 4) 
- hexaploids (ploidy = 6)
- octaploids (ploidy = 8)

To learn more about reading in data, see the docstring `?read_from` or read the [PopGen.jl docs section](https://pdimens.github.io/PopGen.jl/docs/io/file_import) on it.

To learn more about crossing see their docstrings with `?cross`
